/* a11y.h generated by valac 0.56.17, the Vala compiler, do not modify */

#ifndef __SRC_A11Y_H__
#define __SRC_A11Y_H__

#include <gtk/gtk.h>
#include <glib-object.h>
#include <wingpanel.h>
#include <gmodule.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define GETTEXT_PACKAGE "a11y-indicator"
#define LOCALEDIR "/usr/share/locale"

#define A11_Y_TYPE_GREETER_WIDGET (a11_y_greeter_widget_get_type ())
#define A11_Y_GREETER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), A11_Y_TYPE_GREETER_WIDGET, A11YGreeterWidget))
#define A11_Y_GREETER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), A11_Y_TYPE_GREETER_WIDGET, A11YGreeterWidgetClass))
#define A11_Y_IS_GREETER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), A11_Y_TYPE_GREETER_WIDGET))
#define A11_Y_IS_GREETER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), A11_Y_TYPE_GREETER_WIDGET))
#define A11_Y_GREETER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), A11_Y_TYPE_GREETER_WIDGET, A11YGreeterWidgetClass))

typedef struct _A11YGreeterWidget A11YGreeterWidget;
typedef struct _A11YGreeterWidgetClass A11YGreeterWidgetClass;
typedef struct _A11YGreeterWidgetPrivate A11YGreeterWidgetPrivate;

#define A11_Y_TYPE_INDICATOR (a11_y_indicator_get_type ())
#define A11_Y_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), A11_Y_TYPE_INDICATOR, A11YIndicator))
#define A11_Y_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), A11_Y_TYPE_INDICATOR, A11YIndicatorClass))
#define A11_Y_IS_INDICATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), A11_Y_TYPE_INDICATOR))
#define A11_Y_IS_INDICATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), A11_Y_TYPE_INDICATOR))
#define A11_Y_INDICATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), A11_Y_TYPE_INDICATOR, A11YIndicatorClass))

typedef struct _A11YIndicator A11YIndicator;
typedef struct _A11YIndicatorClass A11YIndicatorClass;
typedef struct _A11YIndicatorPrivate A11YIndicatorPrivate;

#define A11_Y_TYPE_SESSION_WIDGET (a11_y_session_widget_get_type ())
#define A11_Y_SESSION_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), A11_Y_TYPE_SESSION_WIDGET, A11YSessionWidget))
#define A11_Y_SESSION_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), A11_Y_TYPE_SESSION_WIDGET, A11YSessionWidgetClass))
#define A11_Y_IS_SESSION_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), A11_Y_TYPE_SESSION_WIDGET))
#define A11_Y_IS_SESSION_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), A11_Y_TYPE_SESSION_WIDGET))
#define A11_Y_SESSION_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), A11_Y_TYPE_SESSION_WIDGET, A11YSessionWidgetClass))

typedef struct _A11YSessionWidget A11YSessionWidget;
typedef struct _A11YSessionWidgetClass A11YSessionWidgetClass;
typedef struct _A11YSessionWidgetPrivate A11YSessionWidgetPrivate;

struct _A11YGreeterWidget {
	GtkGrid parent_instance;
	A11YGreeterWidgetPrivate * priv;
};

struct _A11YGreeterWidgetClass {
	GtkGridClass parent_class;
};

struct _A11YIndicator {
	WingpanelIndicator parent_instance;
	A11YIndicatorPrivate * priv;
};

struct _A11YIndicatorClass {
	WingpanelIndicatorClass parent_class;
};

struct _A11YSessionWidget {
	GtkGrid parent_instance;
	A11YSessionWidgetPrivate * priv;
};

struct _A11YSessionWidgetClass {
	GtkGridClass parent_class;
};

VALA_EXTERN GType a11_y_greeter_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (A11YGreeterWidget, g_object_unref)
VALA_EXTERN A11YGreeterWidget* a11_y_greeter_widget_new (void);
VALA_EXTERN A11YGreeterWidget* a11_y_greeter_widget_construct (GType object_type);
VALA_EXTERN GType a11_y_indicator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (A11YIndicator, g_object_unref)
VALA_EXTERN A11YIndicator* a11_y_indicator_new (WingpanelIndicatorManagerServerType indicator_server_type);
VALA_EXTERN A11YIndicator* a11_y_indicator_construct (GType object_type,
                                          WingpanelIndicatorManagerServerType indicator_server_type);
VALA_EXTERN WingpanelIndicatorManagerServerType a11_y_indicator_get_server_type (A11YIndicator* self);
VALA_EXTERN void a11_y_indicator_set_server_type (A11YIndicator* self,
                                      WingpanelIndicatorManagerServerType value);
VALA_EXTERN WingpanelIndicator* get_indicator (GModule* module,
                                   WingpanelIndicatorManagerServerType server_type);
VALA_EXTERN GType a11_y_session_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (A11YSessionWidget, g_object_unref)
VALA_EXTERN A11YSessionWidget* a11_y_session_widget_new (void);
VALA_EXTERN A11YSessionWidget* a11_y_session_widget_construct (GType object_type);

G_END_DECLS

#endif
